import '../assets/css/sdpi.css';
import '../assets/css/styles.css';
import { default as EventEmitter } from 'eventemitter3';
import { isSomething } from 'ts-type-guards';
import Details from "./elements/Details";
import HtmlElement from "./elements/details/HtmlElement";
import HtmlElementInterface from "./HtmlElementInterface";
import Dropdown from './elements/Dropdown';
import Input from './elements/Input';
function isValueElementBag(value) {
    return (isSomething(value)
        && value.name !== undefined
        && value.element !== undefined);
}
export default class FormBuilder {
    constructor(initialData) {
        this.elementBag = [];
        this.eventEmitter = new EventEmitter();
        this.initialData = initialData;
    }
    getFormData() {
        const data = this.initialData;
        const valueElements = this.elementBag.filter(isValueElementBag);
        for (const element of valueElements) {
            data[element.name] = element.element.value;
        }
        return data;
    }
    setFormData(data) {
        const valueElements = this.elementBag.filter(isValueElementBag);
        for (const element of valueElements) {
            element.element.setValue(data[element.name]);
        }
    }
    appendTo(element) {
        for (const formElement of this.elementBag) {
            if (isValueElementBag(formElement)) {
                element.append(formElement.element.getHtmlElement());
            }
            else {
                element.append(formElement.getHtmlElement());
            }
        }
    }
    addElement(name, value) {
        this.elementBag.push({ element: value, name });
        value.setValue(this.initialData[name]);
    }
    addHtml(element) {
        this.elementBag.push(element);
    }
    addHtmlElement(element) {
        this.elementBag.push(new HtmlElement(element));
    }
    createInput() {
        return this.addEventsToElement(new Input());
    }
    createDropdown() {
        return this.addEventsToElement(new Dropdown());
    }
    createDetails() {
        const details = new Details();
        details.onLinkClick((link) => this.eventEmitter.emit('click-link', link));
        return details;
    }
    on(event, callback) {
        this.eventEmitter.on(event, callback);
    }
    addEventsToElement(element) {
        element.on('change-value', () => this.onChangeElementValue());
        this.eventEmitter.on('change-settings', () => element.reportSettingsChange());
        return element;
    }
    onChangeElementValue() {
        this.eventEmitter.emit('change-settings');
    }
}
