import { default as EventEmitter } from 'eventemitter3';
import Headline from "./details/Headline";
import HtmlElement from "./details/HtmlElement";
import Paragraph from "./details/Paragraph";
import Summary from "./details/Summary";
import HtmlElementInterface from "../HtmlElementInterface";
export default class Details {
    constructor() {
        this.elements = [];
        this.eventEmitter = new EventEmitter();
    }
    getHtmlElement() {
        const detailsElement = document.createElement('details');
        for (const element of this.elements) {
            detailsElement.append(element.getHtmlElement());
        }
        return detailsElement;
    }
    addSummary(text) {
        this.elements.push(new Summary(text));
        return this;
    }
    addHeadline(text) {
        this.elements.push(new Headline(text));
        return this;
    }
    addParagraph(text) {
        const paragraph = new Paragraph(text);
        paragraph.onLinkClick((event) => this.eventEmitter.emit('click', event));
        this.elements.push(paragraph);
        return this;
    }
    addElement(element) {
        this.elements.push(new HtmlElement(element));
        return this;
    }
    onLinkClick(callback) {
        this.eventEmitter.on('click', callback);
    }
}
