import { default as EventEmitter } from 'eventemitter3';
import { is } from 'ts-type-guards';
import LinkHelper from "../../helper/LinkHelper";
import HtmlElementInterface from "../../HtmlElementInterface";
export default class Paragraph {
    constructor(text) {
        this.eventEmitter = new EventEmitter();
        this.linkHelper = new LinkHelper();
        this.text = text;
    }
    getHtmlElement() {
        let element = document.createElement('p');
        const text = this.text;
        const links = this.linkHelper.extractLinks(text);
        if (links.length > 0) {
            element = this.linkHelper.addLinkedText(element, text, links);
            for (const linkElement of element.querySelectorAll('a'))
                linkElement.addEventListener('click', (event) => {
                    if (is(HTMLAnchorElement)(event.target)) {
                        event.preventDefault();
                        this.eventEmitter.emit('click', event.target);
                    }
                });
            return element;
        }
        element.innerHTML = text;
        return element;
    }
    onLinkClick(callback) {
        this.eventEmitter.on('click', callback);
    }
}
